@@ -11,12 +11,13 @@ sys.path.insert(0, os.path.dirname(os.path.abspath(__file__)))
 import tornado.ioloop
 import tornado.web
 
+from server.task.check_cookie_task import CheckCookieTask
 from common.logger_factory import LoggerFactory
 from constant.system_constant import SystemConstant
 from context.context_utils import ContextUtils
 from entity.server_config_entity import ServerConfigEntity
-from server.admin_http_handler import AdminHtmlHandler, AdminHttpApiHandler
-from server.heart_beat_task import HeartBeatTask
+from server.admin_http_handler import AdminHtmlHandler, AdminHttpApiHandler, ShowVariableHandler
+from server.task.heart_beat_task import HeartBeatTask
 from server.tcp_forward_client import TcpForwardClient
 from server.websocket_handler import MyWebSocketaHandler
 
@@ -46,7 +47,7 @@ config_s.json example:
         "admin_password": "new_password"
     }
 }
-""")
+""", version=SystemConstant.VERSION)
     parser.add_option("-c", "--config",
                       type='str',
                       dest='config',
@@ -88,8 +89,10 @@ def signal_handler(sig, frame):
 
 
 def main():
+    print('github: ', SystemConstant.GITHUB)
     signal.signal(signal.SIGINT, signal_handler)
     server_config = load_config()
+    ContextUtils.set_cookie_to_time({})
     ContextUtils.set_password(server_config['password'])
     ContextUtils.set_websocket_path(server_config['path'])
     ContextUtils.set_port(int(server_config['port']))
@@ -101,6 +104,7 @@ def main():
     websocket_path = ContextUtils.get_websocket_path()
     admin_html_path = websocket_path + ('' if websocket_path.endswith('/') else '/') + SystemConstant.ADMIN_PATH  # 管理网页路径
     admin_api_path = websocket_path + ('' if websocket_path.endswith('/') else '/') + SystemConstant.ADMIN_PATH + '/api'  # 管理api路径
+    show_variable_path = websocket_path + ('' if websocket_path.endswith('/') else '/') + SystemConstant.ADMIN_PATH + '/show_variable'  # 管理api路径
     status_url_path = websocket_path + ('' if websocket_path.endswith('/') else '/') + SystemConstant.ADMIN_PATH + '/static'  # static
     static_path = os.path.join(os.path.dirname(__file__), 'server', 'template')
     template_path = os.path.join(os.path.dirname(__file__), 'server', 'template')
@@ -116,13 +120,16 @@ def main():
         handlers.extend([
             (admin_html_path, AdminHtmlHandler),
             (admin_api_path, AdminHttpApiHandler),
-
+            (show_variable_path, ShowVariableHandler)
         ])
     app = tornado.web.Application(handlers, static_path=static_path, static_url_prefix=status_url_path, template_path=template_path)
     app.listen(ContextUtils.get_port(), chunk_size=65536 * 2)
     LoggerFactory.get_logger().info(f'start server at port {ContextUtils.get_port()}, websocket_path: {websocket_path}, admin_path: {admin_html_path}')
     heart_beat_task = HeartBeatTask(asyncio.get_event_loop())
+    # create interval task
+    check_cookie_task = CheckCookieTask()
     tornado.ioloop.PeriodicCallback(heart_beat_task.run, SystemConstant.HEART_BEAT_INTERVAL * 1000).start()
+    tornado.ioloop.PeriodicCallback(check_cookie_task.run, 3600 * 1000).start()
     tornado.ioloop.IOLoop.current().start()
 
 
